@@ -1,8 +1,8 @@
 package Dist::Zilla::Plugin::UploadToGoogleCode;
 use strict;
 use warnings;
-# ABSTRACT: upload your dist to Google Code (experimental)
-our $VERSION = '0.003'; # VERSION
+# ABSTRACT: upload your dist to Google Code (deprecated)
+our $VERSION = '0.004'; # VERSION
 use Moose;
 with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 
@@ -164,22 +164,24 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Dist::Zilla::Plugin::UploadToGoogleCode - upload your dist to Google Code (experimental)
+Dist::Zilla::Plugin::UploadToGoogleCode - upload your dist to Google Code (deprecated)
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
+B<DEPRECATED>: Google code L<shut down|http://google-opensource.blogspot.com/2015/03/farewell-to-google-code.html>
+
 If loaded, this plugin will allow the F<release> command to upload to Google Code.
 
 =head1 DESCRIPTION
@@ -226,6 +228,8 @@ This is a hashref of defaults loaded from F<~/.googlecode-identity>.
 
 =head1 AVAILABILITY
 
+The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-UploadToGoogleCode/>.
+
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::UploadToGoogleCode/>.
@@ -252,4 +256,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
